@@ -22,17 +22,34 @@ format_variables_acs <- function(variables) {
 
 }
 
-load_data_acs <- function(geography, formatted_variables, key, endyear, state = NULL, county = NULL) {
+load_data_acs <- function(geography, formatted_variables, key, endyear, state = NULL, county = NULL, survey) {
 
-  base <- paste0("https://api.census.gov/data/",
+  if (survey == "acs1") {
+    survey <- "acs/acs1"
+  }
+
+  base <- paste("https://api.census.gov/data",
                  as.character(endyear),
-                 "/acs5")
+                 survey, sep = "/")
 
-  if (grepl("DP", formatted_variables)) {
+  if (grepl("^DP", formatted_variables)) {
     message("Using the ACS Data Profile")
     base <- paste0(base, "/profile")
   }
 
+  if (grepl("^S[0-9].", formatted_variables)) {
+    message("Using the ACS Subject Tables")
+    if (survey == "acs1") {
+      base <- paste("https://api.census.gov/data",
+                    as.character(endyear),
+                    "subject",
+                    sep = "/")
+    } else {
+      base <- paste0(base, "/subject")
+
+    }
+  }
+
   if (!is.null(state)) {
 
     state <- map_chr(state, function(x) {
@@ -84,7 +101,7 @@ load_data_acs <- function(geography, formatted_variables, key, endyear, state =
   content <- content(call, as = "text")
 
   validate_call(content = content, geography = geography, year = endyear,
-                dataset = "acs5")
+                dataset = survey)
 
   dat <- tbl_df(fromJSON(content))
 
@@ -186,6 +203,15 @@ load_data_decennial <- function(geography, variables, key, year,
 
   content <- content(call, as = "text")
 
+  # Fix issue in SF3 2000 API - https://github.com/walkerke/tidycensus/issues/22
+  if (year == 2000 & sumfile == "sf3") {
+    content <- str_replace(content, 'O"Brien', "O'Brien")
+    content <- str_replace(content, 'Prince George"s', "Prince George's")
+    content <- str_replace(content, 'Queen Anne"s', "Queen Anne's")
+    content <- str_replace(content, 'St. Mary"s', "St. Mary's")
+
+  }
+
   validate_call(content = content, geography = geography, year = year,
                 dataset = sumfile)
 
@@ -233,5 +259,5 @@ load_data_decennial <- function(geography, variables, key, year,
 
   return(dat)
 
-
 }
+
